@@ -10,7 +10,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(:all);
 use PDF::Table;
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 =head1 NAME
 
@@ -615,7 +615,7 @@ sub heading
     # but smaller than the top margin
     my $bottommargin = defined $options{bottommargin}
         ? $options{bottommargin}
-        : $self->_line_height($size, 0.4);;
+        : $self->_line_height($size, 0.4);
 
     $self->_down($bottommargin);
 }
@@ -699,6 +699,7 @@ sub text
         %options
     );
 
+    my @last_unused;
     while ($rc) {
         # new page
         $page   = $self->add_page;
@@ -713,7 +714,15 @@ sub text
             %options,
         );
         $self->_set_is_new_page(0);
-        last unless grep $_->{text}, @$unused;
+        last unless grep length $_->{text}, @$unused;
+
+        # We need a safety mechanism in case column() does not successfully
+        # print any of the text. In this situation, an infinite loop would
+        # occur, so look for this condition and bail out if so.
+        my @this_unused = grep length $_, map $_->{text}, @$unused;
+        croak "Unable to print text to PDF: @this_unused"
+            if "@last_unused" eq "@this_unused";
+        @last_unused = @this_unused;
     }
 
     $self->_set__y($next_y);
